..
    DO NOT EDIT
    This file is automatically generated with copier using https://codeberg.org/slidge/legacy-module-template

matridge
========

.. sidebar:: Useful links

   `Source <https://codeberg.org/slidge/matridge>`_

   `Chat room <xmpp:slidge@conference.nicoco.fr?join>`_

   `Bug tracker <https://codeberg.org/slidge/matridge/issues>`_


A
`feature-rich <user/features.html>`_
`Matrix <https://matrix.org>`_ to
`XMPP <https://xmpp.org/>`_ puppeteering
`gateway <https://xmpp.org/extensions/xep-0100.html>`_, based on
`slidge <https://slidge.im>`_ and
`nio <https://matrix-nio.readthedocs.io/>`_.

.. toctree::
   :maxdepth: 3

   admin/index
   user/index
   contributing
   autoapi/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
